@@ -113,6 +113,7 @@ SITE_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
 # A list of additional installed applications.
 
 INSTALLED_APPS = (
+
     "django.contrib.sessions",
     "django.contrib.auth",
     "django.contrib.contenttypes",
@@ -122,13 +123,16 @@ INSTALLED_APPS = (
     "django.contrib.admin",
     "django.contrib.sitemaps",
 
-    "optimizations",
+    "sorl.thumbnail",
+    "compressor",
+
+    "cms",
+
     "reversion",
     "usertools",
     "historylinks",
     "watson",
 
-    "cms",
     "cms.apps.pages",
     "cms.apps.links",
     "cms.apps.media",
@@ -149,25 +153,11 @@ STATICFILES_DIRS = (
     os.path.join(SITE_ROOT, "static"),
 )
 
-STATIC_ASSETS = {
-    "default": {
-        "js": {
-            "include": (
-                "js/vendor/jquery.js",
-                "js/foundation/foundation.js",
-                "js/*.js",
-            ),
-            "exclude": (
-                "js/jquery.cms.pages.js",
-            ),
-        },
-        "css": {
-            "include": (
-                "css/screen.css",
-            ),
-        },
-    },
-}
+STATICFILES_FINDERS = (
+    'django.contrib.staticfiles.finders.FileSystemFinder',
+    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
+    'compressor.finders.CompressorFinder',
+)
 
 # Dispatch settings.
 
@@ -185,6 +175,17 @@ MIDDLEWARE_CLASSES = (
     "cms.apps.pages.middleware.PageMiddleware",
 )
 
+PASSWORD_HASHERS = (
+    'django.contrib.auth.hashers.BCryptSHA256PasswordHasher',
+    'django.contrib.auth.hashers.BCryptPasswordHasher',
+    'django.contrib.auth.hashers.PBKDF2PasswordHasher',
+    'django.contrib.auth.hashers.PBKDF2SHA1PasswordHasher',
+    'django.contrib.auth.hashers.SHA1PasswordHasher',
+    'django.contrib.auth.hashers.MD5PasswordHasher',
+    'django.contrib.auth.hashers.CryptPasswordHasher',
+)
+
+
 ROOT_URLCONF = "{{ project_name }}.urls"
 
 WSGI_APPLICATION = "{{ project_name }}.wsgi.application"
@@ -199,7 +200,6 @@ MESSAGE_STORAGE = "django.contrib.messages.storage.cookie.CookieStorage"
 
 SITE_ID = 1
 
-
 # Absolute path to the directory where templates are stored.
 
 TEMPLATE_DIRS = (
@@ -233,13 +233,7 @@ CACHE_MIDDLEWARE_KEY_PREFIX = "{{ project_name }}"
 CACHES = {
     "default": {
         "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
-    },
-    # Used for efficient caching of static assets.
-    "optimizations": {
-        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
-        "TIMEOUT": 60 * 60 * 24,
-        "LOCATION": "optimizations",
-    },
+    }
 }
 
 
